tmuxp
=====

.. image:: _static/tmuxp-dev-screenshot.png
    :scale: 35%
    :width: 100%
    :align: right


tmuxp, a novel approach to manage `tmux(1)`_ (>= 1.8) workspaces through
`python objects`_.

- Basic support for `freezing live sessions`_.
- `Importing`_ from `teamocil`_ and `tmuxinator`_.
- JSON or YAML for `simple`_ or `very elaborate`_ configurations.
- `bash, zsh and tcsh`_ completion.
- Unit tested against against live tmux (1.8 and git). See `travis.yml`_
  file, `tmuxp on Travis CI`_ and `testing`_ page.
- `Documentation`_, `Examples`_, `Internals`_.
- and `much, much more`_.

Ready to begin? See the `Quickstart`_.

.. _tmuxp on Travis CI: http://travis-ci.org/tony/tmuxp
.. _Documentation: http://tmuxp.rtfd.org/
.. _tmux(1): http://tmux.sourceforge.net/
.. _tmuxinator: https://github.com/aziz/tmuxinator
.. _teamocil: https://github.com/remiprev/teamocil
.. _Examples: http://tmuxp.readthedocs.org/en/latest/examples.html
.. _freezing live sessions: http://tmuxp.readthedocs.org/en/latest/cli.html#freeze-sessions
.. _Importing: http://tmuxp.readthedocs.org/en/latest/cli.html#import
.. _travis.yml: http://tmuxp.readthedocs.org/en/latest/developing.html#travis-ci
.. _testing: http://tmuxp.readthedocs.org/en/latest/developing.html#test-runner
.. _python objects: http://tmuxp.readthedocs.org/en/latest/api.html#api
.. _simple: http://tmuxp.readthedocs.org/en/latest/examples.html#short-hand-inline
.. _very elaborate: http://tmuxp.readthedocs.org/en/latest/examples.html#super-advanced-dev-environment
.. _bash, zsh and tcsh: http://tmuxp.readthedocs.org/en/latest/cli.html#bash-completion
.. _much, much more: http://tmuxp.readthedocs.org/en/latest/about.html#minor-tweaks
.. _Quickstart: http://tmuxp.readthedocs.org/en/latest/quickstart.html
.. _Internals: http://tmuxp.readthedocs.org/en/latest/internals.html

Explore:

.. toctree::
    :maxdepth: 2

    about
    cli
    quickstart
    examples
    internals
    developing
    api
    changes
    about_tmux
    glossary

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
